@@ -9,4 +9,9 @@ from .processors import (
 )
 from .serializers import StringSerializer, JsonSerializer, MsgpackSerializer
 from .checkpointers import MemoryCheckPointer, RedisCheckPointer
-from .aggregators import SimpleAggregator, NewlineAggregator, NetstringAggregator, ListAggregator
+from .aggregators import (
+    SimpleAggregator,
+    NewlineAggregator,
+    NetstringAggregator,
+    ListAggregator,
+)
