@@ -133,7 +133,6 @@ class NewlineAggregator(Aggregator):
 
 
 class ListAggregator(Aggregator):
-
     def get_header_size(self, output):
         return 1
 
@@ -188,17 +187,17 @@ class KPLAggregator(Aggregator):
     """
 
     def __init__(self, max_size=None):
-        if max_size is not None:
-            # Ideally, aws_kinesis_agg will make this configurable. See https://github.com/awslabs/kinesis-aggregation/pull/129
-            raise ValidationError("KPL Aggregation does not support max_size.")
-        self.agg = aws_kinesis_agg.aggregator.RecordAggregator()
+        if max_size:
+            self.agg = aws_kinesis_agg.aggregator.RecordAggregator(max_size=max_size)
+        else:
+            self.agg = aws_kinesis_agg.aggregator.RecordAggregator()
 
     def has_items(self):
         return self.agg.get_num_user_records() > 0
 
     def add_item(self, item):
         output = self.serialize(item)
-        record = self.agg.add_user_record('a', output)
+        record = self.agg.add_user_record("a", output)
         self.size = self.agg.get_num_user_records()
         if record:
             size = record.get_size_bytes()
@@ -215,7 +214,7 @@ class KPLAggregator(Aggregator):
             yield OutputItem(size=size, n=n, data=data)
 
     def parse(self, data):
-        message_data = data[len(aws_kinesis_agg.MAGIC):-aws_kinesis_agg.DIGEST_SIZE]
+        message_data = data[len(aws_kinesis_agg.MAGIC) : -aws_kinesis_agg.DIGEST_SIZE]
         ar = aws_kinesis_agg.kpl_pb2.AggregatedRecord()
         ar.ParseFromString(message_data)
         for record in ar.records:
